@@ -6,9 +6,6 @@
 #' @return NULL
 #' @examples
 #' js_support()
-#' @export
-js_support <- function() UseMethod("js_support")
-
 #' @export
 js_support <- function() {
 
@@ -16,6 +13,7 @@ js_support <- function() {
     "name" = character(),
     "js_code" = character(),
     "developer" = character(),
+    "tid" = character(),
     "notes" = character(),
     stringsAsFactors = FALSE
   )
@@ -29,12 +27,14 @@ js_support <- function() {
     name = "Slurm workload manager",
     js_code = "slurm",
     developer = "SchedMD",
+    tid = "SLURM_ARRAY_TASK_ID",
     notes = ""
   ))
   df <- add(df, list(
     name = "Oracle Grid Engine",
     js_code = "ge",
     developer = "Oracle",
+    tid = "SGE_TASK_ID",
     notes = "Formerly known as 'Sun Grid Engine'"
   ))
 
