@@ -18,16 +18,15 @@
 #'     parallelize any code. See
 #'     \url{https://avi-kenny.github.io/SimEngine/parallelization/} for an
 #'     overview of how parallelization works in \pkg{SimEngine}. This option
-#'     will be ignored if the simulation is being run on a cluster computing
-#'     system.
-#' @param n_cores An integer; determines the number of CPUs on which the simulation
-#'     will run if using parallelization. Defaults to one fewer than the number of
-#'     available CPUs on the current host.
+#'     will be ignored (and automatically set to "cluster") if the simulation is
+#'     being run on a cluster computing system.
+#' @param n_cores An integer; determines the number of cores on which the
+#'     simulation will run if using parallelization. Defaults to one fewer than
+#'     the number of available cores.
 #' @param packages A character vector of packages to load and attach
-#' @param stop_at_error A Boolean. If set to TRUE, the simulation will
-#'     stop if it encounters an error in any single replicate Useful for
-#'     debugging.
-#' @param progress_bar A Boolean. If set to FALSE, the progress bar that is
+#' @param stop_at_error Boolean. If set to TRUE, the simulation will stop if it
+#'     encounters an error in any single replicate Useful for debugging.
+#' @param progress_bar Boolean. If set to FALSE, the progress bar that is
 #'     normally displayed while the simulation is running is suppressed.
 #' @param seed An integer; seeds allow for reproducible simulation results. If a
 #'     seed is specified, then consecutive runs of the same simulation with the
@@ -44,9 +43,17 @@
 #'   \code{\link{run}} is called.}
 #'   \item{Even if seeds are used, not all code will be reproducible. For
 #'   example, a simulation that involves getting the current date/time with
-#'   \code{Sys.time()} or dynamically retrieving external data may produce
+#'   \code{Sys.time} or dynamically retrieving external data may produce
 #'   different results on different runs.}
 #' }
+#' @param batch_levels Either NULL or a character vector. If the
+#'     \code{\link{batch}} function is being used within the simulation script,
+#'     this should contain the names of the simulation levels that are used
+#'     within the \code{\link{batch}} function code block. If no simulation
+#'     levels are used within the \code{\link{batch}} function code block,
+#'     specify NULL. See the documentation for the \code{\link{batch}} function.
+#' @param return_batch_id Boolean. If set to TRUE, the batch_id will be included
+#'     as part of the simulation results
 #' @return The original simulation object with a modified configuration
 #' @examples
 #' sim <- new_sim()
@@ -57,20 +64,20 @@
 #' sim
 #' @export
 set_config <- function(
-  sim, num_sim=1000, parallel="none",
-  n_cores=parallel::detectCores()-1, packages=NULL,
-  stop_at_error=FALSE, progress_bar=TRUE, seed=NA
-) UseMethod("set_config")
+  sim, num_sim=1000, parallel="none", n_cores=NA, packages=NULL,
+  stop_at_error=FALSE, progress_bar=TRUE, seed=as.integer(1e9*runif(1)),
+  batch_levels=NA, return_batch_id=FALSE
+) {
+  UseMethod("set_config")
+}
 
 #' @export
 set_config.sim_obj <- function(
-  sim, num_sim=1000, parallel="none",
-  n_cores=parallel::detectCores()-1, packages=NULL,
-  stop_at_error=FALSE, progress_bar=TRUE, seed=NA
+  sim, num_sim=1000, parallel="none", n_cores=NA, packages=NULL,
+  stop_at_error=FALSE, progress_bar=TRUE, seed=as.integer(1e9*runif(1)),
+  batch_levels=NA, return_batch_id=FALSE
 ) {
 
-  handle_errors(sim, "is.sim_obj")
-
   if (length(as.list(match.call()))==2) {
     stop("No configuration options were specified")
   }
@@ -78,7 +85,7 @@ set_config.sim_obj <- function(
   if (!missing(num_sim)) {
     handle_errors(num_sim, "is.numeric")
     sim$config[["num_sim"]] <- num_sim
-    sim$vars$num_sim_total <- nrow(sim$levels_grid)*num_sim
+    sim$vars$num_sim_total <- num_sim_total(sim)
   }
 
   if (!missing(parallel)) {
@@ -95,6 +102,7 @@ set_config.sim_obj <- function(
     handle_errors(packages, "is.character.vec")
     sim$config[["packages"]] <- packages
     for (pkg in packages) { do.call("library", list(pkg)) }
+    sim$vars$session_info = utils::sessionInfo()
   }
 
   if (!missing(stop_at_error)) {
@@ -113,6 +121,26 @@ set_config.sim_obj <- function(
     sim$vars[["seed"]] <- seed
   }
 
+  if (!missing(batch_levels)) {
+    if(!is.null(batch_levels)) {
+      handle_errors(batch_levels, "is.character.vec")
+    }
+    sim$config[["batch_levels"]] <- batch_levels
+    assign(x="batch_levels", value=batch_levels,
+           envir=get(x="..batch_cache", envir=sim$vars$env))
+  }
+
+  if (!missing(return_batch_id)) {
+    handle_errors(return_batch_id, "is.boolean")
+    sim$config[["return_batch_id"]] <- return_batch_id
+  }
+
+  if (!missing(num_sim) || !missing(n_cores) || !missing(batch_levels)) {
+    sim$internals$level_batch_map <- update_level_batch_map(sim)
+    sim$internals$sim_uid_grid <- update_sim_uid_grid(sim)
+    sim$vars$num_sim_total <- num_sim_total(sim)
+  }
+
   set.seed(sim$config[["seed"]])
 
   return (sim)
