@@ -38,11 +38,6 @@
 #' @param keep_errors logical (\code{TRUE} by default); if \code{TRUE}, do not
 #'     try to re-run simulation reps that results in errors previously; if
 #'     \code{FALSE}, attempt to run those reps again
-#' @param keep_extra logical (\code{FALSE} by default); if \code{TRUE}, keep
-#'     previously run simulation reps even if they exceed the current
-#'     \code{num_sim} in config or are from a level that has been dropped; if
-#'     \code{FALSE}, drop excess reps (starting from the last rep for that
-#'     particular simulation level)
 #' @examples
 #' \dontrun{
 #' # The following code creates, runs, and subsequently updates a toy simulation
@@ -58,7 +53,7 @@
 #'     create_data <- function(n) { rnorm(n) }
 #'     sim %<>% set_script(function() {
 #'       data <- create_data(L$n)
-#'       return(mean(data))
+#'       return(list("x"=mean(data)))
 #'     })
 #'     sim %<>% set_levels(n=c(100,1000))
 #'     sim %<>% set_config(num_sim=10)
@@ -69,7 +64,7 @@
 #'   },
 #'
 #'   last = {
-#'     sim %<>% summarize()
+#'     sim %>% summarize()
 #'   },
 #'
 #'   cluster_config = list(js="ge")
@@ -101,7 +96,7 @@
 #'   },
 #'
 #'   last = {
-#'     sim %<>% summarize()
+#'     sim %>% summarize()
 #'   },
 #'
 #'   cluster_config = list(js="ge")
@@ -120,19 +115,17 @@
 #' # qsub -v sim_run='last' -hold_jid 105 update_sim.sh
 #' }
 #' @export
-update_sim_on_cluster <- function(first,
-                              main,
-                              last,
-                              cluster_config,
-                              keep_errors = TRUE,
-                              keep_extra = FALSE) {
+update_sim_on_cluster <- function(
+  first, main, last, cluster_config, keep_errors=T
+) {
 
-  cluster_execute(substitute(first),
-                  substitute(main),
-                  substitute(last),
-                  cluster_config,
-                  keep_errors = keep_errors,
-                  keep_extra = keep_extra,
-                  update_switch = TRUE)
+  cluster_execute(
+    substitute(first),
+    substitute(main),
+    substitute(last),
+    cluster_config,
+    keep_errors = keep_errors,
+    update_switch = T
+  )
 
 }
