@@ -56,17 +56,6 @@ prev_row1 <- sim$results[1,]
 ### update_sim handles errors ###
 test_that("Invalid options throw errors", {
   expect_error(update_sim(sim, keep_errors = "a"), "`keep_errors` must be of type 'logical'")
-  expect_error(update_sim(sim, keep_extra = "a"), "`keep_extra` must be of type 'logical'")
-})
-
-sim %<>% set_levels(
-  estimator = c("estimator_1"),
-  num_patients = c(50, 100),
-  ate = c(-7),
-  new_level = c(1, 2, 3)
-)
-test_that("Adding new level variables throws an error", {
-  expect_error(update_sim(sim), "Updating a sim cannot include new level variables, only new levels.")
 })
 
 # change levels
@@ -203,3 +192,19 @@ test_that("update_sim() works with no levels", {
   expect_equal(nrow(sim$results), 2*prev_nrow)
   expect_equal(sim$results[1,], prev_row1)
 })
+
+# Error handling of invalid levels
+sim <- new_sim()
+create_data <- function(n) { rpois(n, lambda=5) }
+sim %<>% set_levels(n=c(10,100), est="M")
+sim %<>% set_config(num_sim=5)
+sim %<>% set_script(function() {
+  dat <- create_data(L$n)
+  return (list("lambda_hat"=mean(dat)))
+})
+sim %<>% run()
+test_that("Correct handling of updated levels", {
+  expect_error(sim %<>% set_levels(n=c(10,1000), est=c("M","V"), hey=2),
+               paste0("You cannot change the level variables after they are in",
+                      "itially set"))
+})
